==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/CustomForecastHorizonArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.CustomForecastHorizonArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The desired maximum forecast horizon in units of time-series frequency.
 * @property mode Enum to determine forecast horizon selection mode.
 * Expected value is 'Custom'.
 * @property value [Required] Forecast horizon value.
 */
public data class CustomForecastHorizonArgs(
    public val mode: Output<String>,
    public val `value`: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.CustomForecastHorizonArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.CustomForecastHorizonArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.CustomForecastHorizonArgs.builder()
            .mode(mode.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomForecastHorizonArgs].
 */
@PulumiTagMarker
public class CustomForecastHorizonArgsBuilder internal constructor() {
    private var mode: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value Enum to determine forecast horizon selection mode.
     * Expected value is 'Custom'.
     */
    @JvmName("dxkdmnfiexkriotk")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value [Required] Forecast horizon value.
     */
    @JvmName("mobmpbvryghflxyd")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value Enum to determine forecast horizon selection mode.
     * Expected value is 'Custom'.
     */
    @JvmName("dwsahiigmasfaosa")
    public suspend fun mode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value [Required] Forecast horizon value.
     */
    @JvmName("cuoguoxrtmafkddk")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): CustomForecastHorizonArgs = CustomForecastHorizonArgs(
        mode = mode ?: throw PulumiNullFieldException("mode"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/CustomForecastHorizonArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.CustomForecastHorizonArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The desired maximum forecast horizon in units of time-series frequency.
 * @property mode Enum to determine forecast horizon selection mode.
 * Expected value is 'Custom'.
 * @property value [Required] Forecast horizon value.
 */
public data class CustomForecastHorizonArgs(
    public val mode: Output<String>,
    public val `value`: Output<Int>,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.CustomForecastHorizonArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.CustomForecastHorizonArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.CustomForecastHorizonArgs.builder()
            .mode(mode.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomForecastHorizonArgs].
 */
@PulumiTagMarker
public class CustomForecastHorizonArgsBuilder internal constructor() {
    private var mode: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value Enum to determine forecast horizon selection mode.
     * Expected value is 'Custom'.
     */
    @JvmName("ojbkhwbihxmkjjtx")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value [Required] Forecast horizon value.
     */
    @JvmName("crbhkivvbcmrxlrp")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value Enum to determine forecast horizon selection mode.
     * Expected value is 'Custom'.
     */
    @JvmName("gmqgsnspyuomkesl")
    public suspend fun mode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value [Required] Forecast horizon value.
     */
    @JvmName("xmygyknsmqixprty")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): CustomForecastHorizonArgs = CustomForecastHorizonArgs(
        mode = mode ?: throw PulumiNullFieldException("mode"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
